.. toctree::
    :maxdepth: 2

.. Use m2r2 to include and render Markdown file
.. mdinclude:: ../README.md

API Guide
---------

StockMapper
^^^^^^^^^^^

.. automodule:: sec_cik_mapper.StockMapper
    :inherited-members:
    :members:
    :undoc-members:

MutualFundMapper
^^^^^^^^^^^^^^^^

.. automodule:: sec_cik_mapper.MutualFundMapper
    :inherited-members:
    :members:
    :undoc-members:
